@@ -1,21 +1,16 @@
 import sys, os, yaml, json, subprocess
-SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
-sys.path.append(os.path.join(SCRIPT_DIR))
 from pathlib import Path
-# from decouple import config # pip install python-decouple
+SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
+
+sys.path.append(SCRIPT_DIR)
 import aws_batch_utils
 import quick_utils
 import file_utils
 
-SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
 PKG = yaml.safe_load(Path(os.path.join(SCRIPT_DIR, 'packages.yaml')).read_text())
 HOME_PATH = os.path.expanduser('~')
-#AWS_CONFIG = quick_utils.loadJSON(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
-#             if os.path.exists(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
-#             else quick_utils.loadJSON(os.path.join(SCRIPT_DIR,'aws_config_constants.json'))
-#CONTAINER_REGISTRY_URL = AWS_CONFIG['ecr_registry']
-UTILS = ['program_utils.py', 'file_utils.py', 'aws_s3_utils.py', 'quick_utils.py', 'aws_config_constants.json', 'specs.json']
 DEFAULT_REGISTRY = "public.ecr.aws/w7q0j5w1"
+UTILS = ['program_utils.py', 'file_utils.py', 'aws_s3_utils.py', 'quick_utils.py', 'aws_config_constants.json', 'specs.json']
 
 def run_container_local( args ):
     """ Runs a container on the local system (docker run)
@@ -32,6 +27,8 @@ def run_container_local( args ):
     >>> run_container_local( dict(name='test'))
     'sudo docker run test:latest '
 
+    [TODO] figure out a way to not need a full path (/home/...) for local input/output paths
+    [TODO] add docker installation to "pip install bioshed"
     """
     AWS_CONFIG = quick_utils.loadJSON(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
                  if os.path.exists(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
@@ -46,6 +43,11 @@ def run_container_local( args ):
     dockerargs = str(args['dockerargs']).strip()+' ' if 'dockerargs' in args else ''
     container_registry = str(CONTAINER_REGISTRY_URL).rstrip('/')
 
+    # add local output volume if specified (local output needs to be full path)
+    if 'out::/' in pargs:
+        local_outdir = pargs[int(pargs.index('out::/')+5):].split(' ')[0]
+        dockerargs += '-v {}:/output/ '.format(local_outdir)
+
     pullcmd = f'docker pull {container_registry}/{cname}:{ctag}'
     pullcmd = 'sudo '+pullcmd if need_sudo.lower()[0]=='y' else pullcmd
     subprocess.call(pullcmd, shell=True)
@@ -259,6 +261,20 @@ def translate_command_to_docker( args ):
     args_out['docker_commands'] = docker_commands
     return args_out
 
+def specify_output_dir( args ):
+    """ Specify a program output directory if not provided.
+
+    program_args: list of arguments
+    default_dir: default directory if output dir is not provided
+    """
+    default_dir = args['default_dir'] if 'default_dir' in args else ''
+    pargs = quick_utils.format_type(args['program_args'], 'space-str')
+    if 'out::' not in pargs and default_dir != '':
+        pargs = pargs.strip()+' out::/'+default_dir.lstrip('/')
+        return quick_utils.format_type(pargs, 'list')
+    else:
+        return args['program_args']
+
 ###########################################################
 
 def write_dockerfile_conda( args ):
